## Summary

<!-- Brief description of what this PR does -->

## Changes

<!-- Bulleted list of changes -->

-

## Type

- [ ] Bug fix
- [ ] New feature
- [ ] New detector
- [ ] Refactoring
- [ ] Documentation
- [ ] CI/CD

## Checklist

- [ ] Tests pass (`make ci`)
- [ ] No mypy errors
- [ ] No ruff errors
- [ ] Documentation updated (if applicable)
- [ ] Changelog entry added (if applicable)
- [ ] Test coverage maintained or improved

## Test Plan

<!-- How did you test these changes? -->
